function directions = angle2dir(angles)
%directions = ANGLE2DIR(angles)
%
%Convert azimuth/elevation pairs to unit direction vectors
%
%Input:
%  ANGLES     - azimuths and elevations (array N x 2, in degrees)
%
%Output:
%  DIRECTIONS - unit direction vectors (array N x 3)
%
%See also:
%  DIR2ANGLE
%
%Radim Halir, Charles University Prague, halir@ms.mff.cuni.cz
%Created: 2.9.1998
%Last modified 2.9.1998

angles = angles / 180 * pi;
azimuths = angles(:, 1);
elevations = angles(:, 2);
directions = [cos(elevations) .* cos(azimuths), ...
	      cos(elevations) .* sin(azimuths), sin(elevations)];
